import GameKit
import objc
from PyObjCTools.TestSupport import TestCase


class TestGKChallengeEventHandlerHelper(GameKit.NSObject):
    def shouldShowBannerForLocallyReceivedChallenge_(self, a):
        return 1

    def shouldShowBannerForLocallyCompletedChallenge_(self, a):
        return 1

    def shouldShowBannerForRemotelyCompletedChallenge_(self, a):
        return 1


class TestGKChallengeEventHandler(TestCase):
    def testProtocols(self):
        objc.protocolNamed("GKChallengeEventHandlerDelegate")

    def testProtocolMethods(self):
        self.assertResultIsBOOL(
            TestGKChallengeEventHandlerHelper.shouldShowBannerForLocallyReceivedChallenge_
        )
        self.assertResultIsBOOL(
            TestGKChallengeEventHandlerHelper.shouldShowBannerForLocallyCompletedChallenge_
        )
        self.assertResultIsBOOL(
            TestGKChallengeEventHandlerHelper.shouldShowBannerForRemotelyCompletedChallenge_
        )



import GameKit
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestGKError(TestCase):
    def testConstants(self):

        self.assertEqual(GameKit.GKGameSessionErrorUnknown, 1)
        self.assertEqual(GameKit.GKGameSessionErrorNotAuthenticated, 2)
        self.assertEqual(GameKit.GKGameSessionErrorSessionConflict, 3)
        self.assertEqual(GameKit.GKGameSessionErrorSessionNotShared, 4)
        self.assertEqual(GameKit.GKGameSessionErrorConnectionCancelledByUser, 5)
        self.assertEqual(GameKit.GKGameSessionErrorConnectionFailed, 6)
        self.assertEqual(GameKit.GKGameSessionErrorSessionHasMaxConnectedPlayers, 7)
        self.assertEqual(GameKit.GKGameSessionErrorSendDataNotConnected, 8)
        self.assertEqual(GameKit.GKGameSessionErrorSendDataNoRecipients, 9)
        self.assertEqual(GameKit.GKGameSessionErrorSendDataNotReachable, 10)
        self.assertEqual(GameKit.GKGameSessionErrorSendRateLimitReached, 11)
        self.assertEqual(GameKit.GKGameSessionErrorBadContainer, 12)
        self.assertEqual(GameKit.GKGameSessionErrorCloudQuotaExceeded, 13)
        self.assertEqual(GameKit.GKGameSessionErrorNetworkFailure, 14)
        self.assertEqual(GameKit.GKGameSessionErrorCloudDriveDisabled, 15)
        self.assertEqual(GameKit.GKGameSessionErrorInvalidSession, 16)

    @min_os_level("10.12")
    def testConstants10_12(self):
        self.assertIsInstance(GameKit.GKGameSessionErrorDomain, str)



from PyObjCTools.TestSupport import TestCase, min_os_level
import GameKit


class TestGKAccessPoint(TestCase):
    def test_constants(self):
        self.assertEqual(GameKit.GKAccessPointLocationTopLeading, 0)
        self.assertEqual(GameKit.GKAccessPointLocationTopTrailing, 1)
        self.assertEqual(GameKit.GKAccessPointLocationBottomLeading, 2)
        self.assertEqual(GameKit.GKAccessPointLocationBottomTrailing, 3)

    @min_os_level("11.0")
    def test_methods11_0(self):
        self.assertResultIsBOOL(GameKit.GKAccessPoint.isActive)
        self.assertArgIsBOOL(GameKit.GKAccessPoint.setActive_, 0)

        self.assertResultIsBOOL(GameKit.GKAccessPoint.isVisible)
        self.assertResultIsBOOL(GameKit.GKAccessPoint.isPresentingGameCenter)

        self.assertResultIsBOOL(GameKit.GKAccessPoint.showHighlights)
        self.assertArgIsBOOL(GameKit.GKAccessPoint.setShowHighlights_, 0)

        self.assertArgIsBlock(
            GameKit.GKAccessPoint.triggerAccessPointWithHandler_, 0, b"v"
        )
        self.assertArgIsBlock(
            GameKit.GKAccessPoint.triggerAccessPointWithState_handler_, 1, b"v"
        )



import GameKit
from PyObjCTools.TestSupport import TestCase, min_os_level
import objc


class TestGKTurnBasedMatchmakerViewController(TestCase):
    def testProtocols(self):
        objc.protocolNamed("GKTurnBasedMatchmakerViewControllerDelegate")

    @min_os_level("10.8")
    def testMethods(self):
        self.assertResultIsBOOL(
            GameKit.GKTurnBasedMatchmakerViewController.showExistingMatches
        )
        self.assertArgIsBOOL(
            GameKit.GKTurnBasedMatchmakerViewController.setShowExistingMatches_, 0
        )



import GameKit  # noqa: F401
import objc
from PyObjCTools.TestSupport import TestCase


class TestGKAchievementViewController(TestCase):
    def testProtocols(self):
        objc.protocolNamed("GKChallengesViewControllerDelegate")



import GameKit
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestGKNotificationHandler(TestCase):
    @min_os_level("10.8")
    def testMethods10_8(self):
        self.assertArgIsBlock(
            GameKit.GKNotificationBanner.showBannerWithTitle_message_completionHandler_,
            2,
            b"v",
        )
        self.assertArgIsBlock(
            GameKit.GKNotificationBanner.showBannerWithTitle_message_duration_completionHandler_,
            3,
            b"v",
        )



import GameKit
from PyObjCTools.TestSupport import TestCase


class TestGKAchievementDescriptionHelper(GameKit.GKAchievementDescription):
    def isHidden(self):
        return 1

    def isReplayable(self):
        return 1


class TestGKAchievementDescription(TestCase):
    def testMethods(self):
        self.assertArgIsBlock(
            GameKit.GKAchievementDescription.loadAchievementDescriptionsWithCompletionHandler_,
            0,
            b"v@@",
        )

        self.assertResultIsBOOL(TestGKAchievementDescriptionHelper.isHidden)
        self.assertResultIsBOOL(TestGKAchievementDescriptionHelper.isReplayable)

        self.assertArgIsBlock(
            GameKit.GKAchievementDescription.loadImageWithCompletionHandler_, 0, b"v@@"
        )



import GameKit
from PyObjCTools.TestSupport import TestCase


class TestGKDialogController(TestCase):
    def testMethods(self):
        self.assertResultIsBOOL(GameKit.GKDialogController.presentViewController_)



import GameKit
from PyObjCTools.TestSupport import TestCase, min_os_level

GKChallengeComposeCompletionBlock = b"v@Z@"


class TestGKChallenge(TestCase):
    def testConstants(self):
        self.assertEqual(GameKit.GKChallengeStateInvalid, 0)
        self.assertEqual(GameKit.GKChallengeStatePending, 1)
        self.assertEqual(GameKit.GKChallengeStateCompleted, 2)
        self.assertEqual(GameKit.GKChallengeStateDeclined, 3)

    def testMethods(self):
        self.assertArgIsBlock(
            GameKit.GKChallenge.loadReceivedChallengesWithCompletionHandler_, 0, b"v@@"
        )

        self.assertArgIsBlock(
            GameKit.GKAchievement.selectChallengeablePlayerIDs_withCompletionHandler_,
            1,
            b"v@@",
        )

    @min_os_level("10.10")
    def testMethods10_10(self):
        self.assertArgIsBlock(
            GameKit.GKScore.challengeComposeControllerWithMessage_players_completionHandler_,
            2,
            GKChallengeComposeCompletionBlock,
        )
        self.assertArgIsBlock(
            GameKit.GKScore.reportScores_withEligibleChallenges_withCompletionHandler_,
            2,
            b"v@",
        )
        self.assertArgIsBlock(
            GameKit.GKAchievement.challengeComposeControllerWithMessage_players_completionHandler_,
            2,
            GKChallengeComposeCompletionBlock,
        )
        self.assertArgIsBlock(
            GameKit.GKAchievement.selectChallengeablePlayers_withCompletionHandler_,
            1,
            b"v@@",
        )
        self.assertArgIsBlock(
            GameKit.GKAchievement.reportAchievements_withEligibleChallenges_withCompletionHandler_,
            2,
            b"v@",
        )

    @min_os_level("11.0")
    def testMethods11_0(self):
        self.assertArgIsBlock(
            GameKit.GKScore.reportLeaderboardScores_withEligibleChallenges_withCompletionHandler_,
            2,
            b"v@",
        )



import GameKit
from PyObjCTools.TestSupport import TestCase


class TestGKPublicConstants(TestCase):
    def testConstants(self):
        self.assertEqual(GameKit.GKSendDataReliable, 0)
        self.assertEqual(GameKit.GKSendDataUnreliable, 1)

        self.assertEqual(GameKit.GKSessionModeServer, 0)
        self.assertEqual(GameKit.GKSessionModeClient, 1)
        self.assertEqual(GameKit.GKSessionModePeer, 2)

        self.assertEqual(GameKit.GKPeerStateAvailable, 0)
        self.assertEqual(GameKit.GKPeerStateUnavailable, 1)
        self.assertEqual(GameKit.GKPeerStateConnected, 2)
        self.assertEqual(GameKit.GKPeerStateDisconnected, 3)
        self.assertEqual(GameKit.GKPeerStateConnecting, 4)
        self.assertEqual(GameKit.GKPeerStateConnectedRelay, 5)

        self.assertIsInstance(GameKit.GKVoiceChatServiceErrorDomain, str)



import GameKit
from PyObjCTools.TestSupport import TestCase


class TestGKError(TestCase):
    def testConstants(self):
        self.assertEqual(GameKit.GKErrorUnknown, 1)
        self.assertEqual(GameKit.GKErrorCancelled, 2)
        self.assertEqual(GameKit.GKErrorCommunicationsFailure, 3)
        self.assertEqual(GameKit.GKErrorUserDenied, 4)
        self.assertEqual(GameKit.GKErrorInvalidCredentials, 5)
        self.assertEqual(GameKit.GKErrorNotAuthenticated, 6)
        self.assertEqual(GameKit.GKErrorAuthenticationInProgress, 7)
        self.assertEqual(GameKit.GKErrorInvalidPlayer, 8)
        self.assertEqual(GameKit.GKErrorScoreNotSet, 9)
        self.assertEqual(GameKit.GKErrorParentalControlsBlocked, 10)
        self.assertEqual(GameKit.GKErrorPlayerStatusExceedsMaximumLength, 11)
        self.assertEqual(GameKit.GKErrorPlayerStatusInvalid, 12)
        self.assertEqual(GameKit.GKErrorMatchRequestInvalid, 13)
        self.assertEqual(GameKit.GKErrorUnderage, 14)
        self.assertEqual(GameKit.GKErrorGameUnrecognized, 15)
        self.assertEqual(GameKit.GKErrorNotSupported, 16)
        self.assertEqual(GameKit.GKErrorInvalidParameter, 17)
        self.assertEqual(GameKit.GKErrorUnexpectedConnection, 18)
        self.assertEqual(GameKit.GKErrorChallengeInvalid, 19)
        self.assertEqual(GameKit.GKErrorTurnBasedMatchDataTooLarge, 20)
        self.assertEqual(GameKit.GKErrorTurnBasedTooManySessions, 21)
        self.assertEqual(GameKit.GKErrorTurnBasedInvalidParticipant, 22)
        self.assertEqual(GameKit.GKErrorTurnBasedInvalidTurn, 23)
        self.assertEqual(GameKit.GKErrorTurnBasedInvalidState, 24)
        self.assertEqual(GameKit.GKErrorInvitationsDisabled, 25)
        self.assertEqual(GameKit.GKErrorPlayerPhotoFailure, 26)
        self.assertEqual(GameKit.GKErrorUbiquityContainerUnavailable, 27)
        self.assertEqual(GameKit.GKErrorMatchNotConnected, 28)
        self.assertEqual(GameKit.GKErrorGameSessionRequestInvalid, 29)
        self.assertEqual(GameKit.GKErrorRestrictedToAutomatch, 30)
        self.assertEqual(GameKit.GKErrorAPINotAvailable, 31)
        self.assertEqual(GameKit.GKErrorNotAuthorized, 32)
        self.assertEqual(GameKit.GKErrorConnectionTimeout, 33)
        self.assertEqual(GameKit.GKErrorAPIObsolete, 34)
        self.assertEqual(GameKit.GKErrorFriendListDescriptionMissing, 100)
        self.assertEqual(GameKit.GKErrorFriendListRestricted, 101)
        self.assertEqual(GameKit.GKErrorFriendListDenied, 102)
        self.assertEqual(GameKit.GKErrorFriendRequestNotAvailable, 103)



import GameKit  # noqa: F401
import objc
from PyObjCTools.TestSupport import TestCase, min_sdk_level


class TestGKGameSessionEventListener(TestCase):
    @min_sdk_level("10.12")
    def testProtocols(self):
        objc.protocolNamed("GKGameSessionEventListener")



import GameKit
from PyObjCTools.TestSupport import TestCase, min_os_level


if hasattr(GameKit, "GKLeaderboardSet"):

    class TestGKLeaderboardSetHelper(GameKit.GKLeaderboardSet):
        def loadImageWithCompletionHandler_(self, h):
            pass


class TestGKLeaderboardSet(TestCase):
    @min_os_level("10.10")
    def testMethods(self):
        self.assertArgIsBlock(
            GameKit.GKLeaderboardSet.loadLeaderboardSetsWithCompletionHandler_,
            0,
            b"v@@",
        )
        self.assertArgIsBlock(
            GameKit.GKLeaderboardSet.loadLeaderboardsWithCompletionHandler_, 0, b"v@@"
        )
        self.assertArgIsBlock(
            TestGKLeaderboardSetHelper.loadImageWithCompletionHandler_, 0, b"v@@"
        )

    @min_os_level("11.0")
    def testMethods11_0(self):
        self.assertArgIsBlock(
            GameKit.GKLeaderboardSet.loadLeaderboardsWithHandler_, 0, b"v@@"
        )



# This file is generated by objective.metadata
#
# Last update: Sun Aug  1 09:34:22 2021
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$GKErrorDomain$GKExchangeTimeoutDefault@d$GKExchangeTimeoutNone@d$GKGameSessionErrorDomain$GKPlayerAuthenticationDidChangeNotificationName$GKPlayerDidChangeNotificationName$GKPlayerIDNoLongerAvailable$GKSessionErrorDomain$GKTurnTimeoutDefault@d$GKTurnTimeoutNone@d$GKVoiceChatServiceErrorDomain$"""
enums = """$GKAccessPointLocationBottomLeading@2$GKAccessPointLocationBottomTrailing@3$GKAccessPointLocationTopLeading@0$GKAccessPointLocationTopTrailing@1$GKAuthenticatingWithAuthKitInvocation@2$GKAuthenticatingWithGreenBuddyUI@1$GKAuthenticatingWithoutUI@0$GKChallengeStateCompleted@2$GKChallengeStateDeclined@3$GKChallengeStateInvalid@0$GKChallengeStatePending@1$GKConnectionStateConnected@1$GKConnectionStateNotConnected@0$GKErrorAPINotAvailable@31$GKErrorAPIObsolete@34$GKErrorAuthenticationInProgress@7$GKErrorCancelled@2$GKErrorChallengeInvalid@19$GKErrorCommunicationsFailure@3$GKErrorConnectionTimeout@33$GKErrorFriendListDenied@102$GKErrorFriendListDescriptionMissing@100$GKErrorFriendListRestricted@101$GKErrorFriendRequestNotAvailable@103$GKErrorGameSessionRequestInvalid@29$GKErrorGameUnrecognized@15$GKErrorInvalidCredentials@5$GKErrorInvalidParameter@17$GKErrorInvalidPlayer@8$GKErrorInvitationsDisabled@25$GKErrorMatchNotConnected@28$GKErrorMatchRequestInvalid@13$GKErrorNotAuthenticated@6$GKErrorNotAuthorized@32$GKErrorNotSupported@16$GKErrorParentalControlsBlocked@10$GKErrorPlayerPhotoFailure@26$GKErrorPlayerStatusExceedsMaximumLength@11$GKErrorPlayerStatusInvalid@12$GKErrorRestrictedToAutomatch@30$GKErrorScoreNotSet@9$GKErrorTurnBasedInvalidParticipant@22$GKErrorTurnBasedInvalidState@24$GKErrorTurnBasedInvalidTurn@23$GKErrorTurnBasedMatchDataTooLarge@20$GKErrorTurnBasedTooManySessions@21$GKErrorUbiquityContainerUnavailable@27$GKErrorUnderage@14$GKErrorUnexpectedConnection@18$GKErrorUnknown@1$GKErrorUserDenied@4$GKFriendsAuthorizationStatusAuthorized@3$GKFriendsAuthorizationStatusDenied@2$GKFriendsAuthorizationStatusNotDetermined@0$GKFriendsAuthorizationStatusRestricted@1$GKGameCenterViewControllerStateAchievements@1$GKGameCenterViewControllerStateChallenges@2$GKGameCenterViewControllerStateDashboard@4$GKGameCenterViewControllerStateDefault@-1$GKGameCenterViewControllerStateLeaderboards@0$GKGameCenterViewControllerStateLocalPlayerFriendsList@5$GKGameCenterViewControllerStateLocalPlayerProfile@3$GKGameSessionErrorBadContainer@12$GKGameSessionErrorCloudDriveDisabled@15$GKGameSessionErrorCloudQuotaExceeded@13$GKGameSessionErrorConnectionCancelledByUser@5$GKGameSessionErrorConnectionFailed@6$GKGameSessionErrorInvalidSession@16$GKGameSessionErrorNetworkFailure@14$GKGameSessionErrorNotAuthenticated@2$GKGameSessionErrorSendDataNoRecipients@9$GKGameSessionErrorSendDataNotConnected@8$GKGameSessionErrorSendDataNotReachable@10$GKGameSessionErrorSendRateLimitReached@11$GKGameSessionErrorSessionConflict@3$GKGameSessionErrorSessionHasMaxConnectedPlayers@7$GKGameSessionErrorSessionNotShared@4$GKGameSessionErrorUnknown@1$GKInviteRecipientResponseAccepted@0$GKInviteRecipientResponseDeclined@1$GKInviteRecipientResponseFailed@2$GKInviteRecipientResponseIncompatible@3$GKInviteRecipientResponseNoAnswer@5$GKInviteRecipientResponseUnableToConnect@4$GKInviteeResponseAccepted@0$GKInviteeResponseDeclined@1$GKInviteeResponseFailed@2$GKInviteeResponseIncompatible@3$GKInviteeResponseNoAnswer@5$GKInviteeResponseUnableToConnect@4$GKLeaderboardPlayerScopeFriendsOnly@1$GKLeaderboardPlayerScopeGlobal@0$GKLeaderboardTimeScopeAllTime@2$GKLeaderboardTimeScopeToday@0$GKLeaderboardTimeScopeWeek@1$GKLeaderboardTypeClassic@0$GKLeaderboardTypeRecurring@1$GKMatchSendDataReliable@0$GKMatchSendDataUnreliable@1$GKMatchTypeHosted@1$GKMatchTypePeerToPeer@0$GKMatchTypeTurnBased@2$GKMatchmakingModeAutomatchOnly@2$GKMatchmakingModeDefault@0$GKMatchmakingModeInviteOnly@3$GKMatchmakingModeNearbyOnly@1$GKPeerStateAvailable@0$GKPeerStateConnected@2$GKPeerStateConnectedRelay@5$GKPeerStateConnecting@4$GKPeerStateDisconnected@3$GKPeerStateUnavailable@1$GKPhotoSizeNormal@1$GKPhotoSizeSmall@0$GKPlayerStateConnected@1$GKPlayerStateDisconnected@2$GKPlayerStateUnknown@0$GKSendDataReliable@0$GKSendDataUnreliable@1$GKSessionCancelledError@30504$GKSessionCannotEnableError@30509$GKSessionConnectionClosedError@30506$GKSessionConnectionFailedError@30505$GKSessionConnectivityError@30201$GKSessionDataTooBigError@30507$GKSessionDeclinedError@30502$GKSessionInProgressError@30510$GKSessionInternalError@30203$GKSessionInvalidParameterError@30500$GKSessionModeClient@1$GKSessionModePeer@2$GKSessionModeServer@0$GKSessionNotConnectedError@30508$GKSessionPeerNotFoundError@30501$GKSessionSystemError@30205$GKSessionTimedOutError@30503$GKSessionTransportError@30202$GKSessionUnknownError@30204$GKTransportTypeReliable@1$GKTransportTypeUnreliable@0$GKTurnBasedExchangeStatusActive@1$GKTurnBasedExchangeStatusCanceled@4$GKTurnBasedExchangeStatusComplete@2$GKTurnBasedExchangeStatusResolved@3$GKTurnBasedExchangeStatusUnknown@0$GKTurnBasedMatchOutcomeCustomRange@16711680$GKTurnBasedMatchOutcomeFirst@6$GKTurnBasedMatchOutcomeFourth@9$GKTurnBasedMatchOutcomeLost@3$GKTurnBasedMatchOutcomeNone@0$GKTurnBasedMatchOutcomeQuit@1$GKTurnBasedMatchOutcomeSecond@7$GKTurnBasedMatchOutcomeThird@8$GKTurnBasedMatchOutcomeTied@4$GKTurnBasedMatchOutcomeTimeExpired@5$GKTurnBasedMatchOutcomeWon@2$GKTurnBasedMatchStatusEnded@2$GKTurnBasedMatchStatusMatching@3$GKTurnBasedMatchStatusOpen@1$GKTurnBasedMatchStatusUnknown@0$GKTurnBasedParticipantStatusActive@4$GKTurnBasedParticipantStatusDeclined@2$GKTurnBasedParticipantStatusDone@5$GKTurnBasedParticipantStatusInvited@1$GKTurnBasedParticipantStatusMatching@3$GKTurnBasedParticipantStatusUnknown@0$GKVoiceChatPlayerConnected@0$GKVoiceChatPlayerConnecting@4$GKVoiceChatPlayerDisconnected@1$GKVoiceChatPlayerSilent@3$GKVoiceChatPlayerSpeaking@2$GKVoiceChatServiceAudioUnavailableError@32005$GKVoiceChatServiceClientMissingRequiredMethodsError@32007$GKVoiceChatServiceInternalError@32000$GKVoiceChatServiceInvalidCallIDError@32004$GKVoiceChatServiceInvalidParameterError@32016$GKVoiceChatServiceMethodCurrentlyInvalidError@32012$GKVoiceChatServiceNetworkConfigurationError@32013$GKVoiceChatServiceNoRemotePacketsError@32001$GKVoiceChatServiceOutOfMemoryError@32015$GKVoiceChatServiceRemoteParticipantBusyError@32008$GKVoiceChatServiceRemoteParticipantCancelledError@32009$GKVoiceChatServiceRemoteParticipantDeclinedInviteError@32011$GKVoiceChatServiceRemoteParticipantHangupError@32003$GKVoiceChatServiceRemoteParticipantResponseInvalidError@32010$GKVoiceChatServiceUnableToConnectError@32002$GKVoiceChatServiceUninitializedClientError@32006$GKVoiceChatServiceUnsupportedRemoteVersionError@32014$"""
misc.update({})
aliases = {
    "GKInviteeResponseAccepted": "GKInviteRecipientResponseAccepted",
    "GKInviteeResponseNoAnswer": "GKInviteRecipientResponseNoAnswer",
    "GKInviteeResponseFailed": "GKInviteRecipientResponseFailed",
    "GKInviteeResponseIncompatible": "GKInviteRecipientResponseIncompatible",
    "GKInviteeResponseDeclined": "GKInviteRecipientResponseDeclined",
    "GKInviteeResponseUnableToConnect": "GKInviteRecipientResponseUnableToConnect",
}
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(b"GKAccessPoint", b"isActive", {"retval": {"type": b"Z"}})
    r(b"GKAccessPoint", b"isFocused", {"retval": {"type": b"Z"}})
    r(b"GKAccessPoint", b"isPresentingGameCenter", {"retval": {"type": b"Z"}})
    r(b"GKAccessPoint", b"isVisible", {"retval": {"type": b"Z"}})
    r(b"GKAccessPoint", b"setActive:", {"arguments": {2: {"type": b"Z"}}})
    r(b"GKAccessPoint", b"setFocused:", {"arguments": {2: {"type": b"Z"}}})
    r(b"GKAccessPoint", b"setShowHighlights:", {"arguments": {2: {"type": b"Z"}}})
    r(b"GKAccessPoint", b"showHighlights", {"retval": {"type": b"Z"}})
    r(
        b"GKAccessPoint",
        b"triggerAccessPointWithHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(
        b"GKAccessPoint",
        b"triggerAccessPointWithState:handler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(
        b"GKAchievement",
        b"challengeComposeControllerWithMessage:players:completionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"Z"},
                            3: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(b"GKAchievement", b"isCompleted", {"retval": {"type": b"Z"}})
    r(b"GKAchievement", b"isHidden", {"retval": {"type": b"Z"}})
    r(
        b"GKAchievement",
        b"loadAchievementsWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKAchievement",
        b"reportAchievementWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKAchievement",
        b"reportAchievements:withCompletionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKAchievement",
        b"reportAchievements:withEligibleChallenges:withCompletionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKAchievement",
        b"resetAchievementsWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKAchievement",
        b"selectChallengeablePlayerIDs:withCompletionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKAchievement",
        b"selectChallengeablePlayers:withCompletionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKAchievement",
        b"setShowsCompletionBanner:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"GKAchievement", b"showsCompletionBanner", {"retval": {"type": b"Z"}})
    r(b"GKAchievementDescription", b"isHidden", {"retval": {"type": b"Z"}})
    r(b"GKAchievementDescription", b"isReplayable", {"retval": {"type": b"Z"}})
    r(
        b"GKAchievementDescription",
        b"loadAchievementDescriptionsWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKAchievementDescription",
        b"loadImageWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKChallenge",
        b"challengeComposeControllerWithMessage:players:completionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"Z"},
                            3: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKChallenge",
        b"loadReceivedChallengesWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKChallenge",
        b"reportScores:withEligibleChallenges:withCompletionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKCloudPlayer",
        b"getCurrentSignedInPlayerForContainer:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(b"GKDialogController", b"presentViewController:", {"retval": {"type": b"Z"}})
    r(
        b"GKGameSession",
        b"clearBadgeForPlayers:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKGameSession",
        b"createSessionInContainer:withTitle:maxConnectedPlayers:completionHandler:",
        {
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKGameSession",
        b"getShareURLWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKGameSession",
        b"loadDataWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKGameSession",
        b"loadSessionWithIdentifier:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKGameSession",
        b"loadSessionsInContainer:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKGameSession",
        b"removeSessionWithIdentifier:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKGameSession",
        b"saveData:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKGameSession",
        b"sendData:withTransportType:completionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKGameSession",
        b"sendMessageWithLocalizedFormatKey:arguments:data:toPlayers:badgePlayers:completionHandler:",
        {
            "arguments": {
                6: {"type": b"Z"},
                7: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                },
            }
        },
    )
    r(
        b"GKGameSession",
        b"setConnectionState:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(b"GKInvite", b"isHosted", {"retval": {"type": b"Z"}})
    r(b"GKLeaderboard", b"isLoading", {"retval": {"type": b"Z"}})
    r(
        b"GKLeaderboard",
        b"loadCategoriesWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                            3: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKLeaderboard",
        b"loadEntriesForPlayerScope:timeScope:range:completionHandler:",
        {
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                            3: {"type": b"q"},
                            4: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKLeaderboard",
        b"loadEntriesForPlayers:timeScope:completionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                            3: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKLeaderboard",
        b"loadImageWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKLeaderboard",
        b"loadLeaderboardsWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKLeaderboard",
        b"loadLeaderboardsWithIDs:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKLeaderboard",
        b"loadPreviousOccurrenceWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKLeaderboard",
        b"loadScoresWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKLeaderboard",
        b"setDefaultLeaderboard:withCompletionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKLeaderboard",
        b"submitScore:context:player:completionHandler:",
        {
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKLeaderboard",
        b"submitScore:context:player:leaderboardIDs:completionHandler:",
        {
            "arguments": {
                6: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKLeaderboardEntry",
        b"challengeComposeControllerWithMessage:players:completionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"Z"},
                            3: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKLeaderboardSet",
        b"loadImageWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    },
                    "type": "@?",
                }
            }
        },
    )
    r(
        b"GKLeaderboardSet",
        b"loadLeaderboardSetsWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKLeaderboardSet",
        b"loadLeaderboardsWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKLeaderboardSet",
        b"loadLeaderboardsWithHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKLocalPlayer",
        b"authenticateHandler",
        {
            "retval": {
                "callable": {
                    "retval": {"type": b"v"},
                    "arguments": {
                        0: {"type": b"^v"},
                        1: {"type": b"@"},
                        2: {"type": b"@"},
                    },
                }
            }
        },
    )
    r(
        b"GKLocalPlayer",
        b"authenticateWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKLocalPlayer",
        b"deleteSavedGamesWithName:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKLocalPlayer",
        b"fetchItemsForIdentityVerificationSignature:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                            3: {"type": b"@"},
                            4: {"type": b"Q"},
                            5: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKLocalPlayer",
        b"fetchSavedGamesWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKLocalPlayer",
        b"generateIdentityVerificationSignatureWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                            3: {"type": b"@"},
                            4: {"type": b"Q"},
                            5: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(b"GKLocalPlayer", b"isAuthenticated", {"retval": {"type": b"Z"}})
    r(b"GKLocalPlayer", b"isMultiplayerGamingRestricted", {"retval": {"type": b"Z"}})
    r(
        b"GKLocalPlayer",
        b"isPersonalizedCommunicationRestricted",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"GKLocalPlayer",
        b"isPresentingFriendRequestViewController",
        {"retval": {"type": b"Z"}},
    )
    r(b"GKLocalPlayer", b"isUnderage", {"retval": {"type": b"Z"}})
    r(
        b"GKLocalPlayer",
        b"loadChallengableFriendsWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKLocalPlayer",
        b"loadDefaultLeaderboardCategoryIDWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKLocalPlayer",
        b"loadDefaultLeaderboardIdentifierWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKLocalPlayer",
        b"loadFriendPlayersWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKLocalPlayer",
        b"loadFriends:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKLocalPlayer",
        b"loadFriendsAuthorizationStatus:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"q"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKLocalPlayer",
        b"loadFriendsWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKLocalPlayer",
        b"loadFriendsWithIdentifiers:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKLocalPlayer",
        b"loadRecentPlayersWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKLocalPlayer",
        b"presentFriendRequestCreatorFromWindow:error:",
        {"retval": {"type": b"Z"}, "arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"GKLocalPlayer",
        b"resolveConflictingSavedGames:withData:completionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKLocalPlayer",
        b"saveGameData:withName:completionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKLocalPlayer",
        b"setAuthenticateHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKLocalPlayer",
        b"setDefaultLeaderboardCategoryID:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKLocalPlayer",
        b"setDefaultLeaderboardIdentifier:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKMatch",
        b"chooseBestHostPlayerWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKMatch",
        b"chooseBestHostingPlayerWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKMatch",
        b"rematchWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKMatch",
        b"sendData:toPlayers:dataMode:error:",
        {"retval": {"type": b"Z"}, "arguments": {5: {"type_modifier": b"o"}}},
    )
    r(
        b"GKMatch",
        b"sendData:toPlayers:withDataMode:error:",
        {"retval": {"type": b"Z"}, "arguments": {5: {"type_modifier": b"o"}}},
    )
    r(
        b"GKMatch",
        b"sendDataToAllPlayers:withDataMode:error:",
        {"retval": {"type": b"Z"}, "arguments": {4: {"type_modifier": b"o"}}},
    )
    r(
        b"GKMatchRequest",
        b"inviteeResponseHandler",
        {
            "retval": {
                "callable": {
                    "retval": {"type": b"v"},
                    "arguments": {
                        0: {"type": b"^v"},
                        1: {"type": b"@"},
                        2: {"type": sel32or64(b"i", b"q")},
                    },
                }
            }
        },
    )
    r(
        b"GKMatchRequest",
        b"recipientResponseHandler",
        {
            "retval": {
                "callable": {
                    "retval": {"type": b"v"},
                    "arguments": {
                        0: {"type": b"^v"},
                        1: {"type": b"@"},
                        2: {"type": sel32or64(b"i", b"q")},
                    },
                }
            }
        },
    )
    r(b"GKMatchRequest", b"restrictToAutomatch", {"retval": {"type": b"Z"}})
    r(
        b"GKMatchRequest",
        b"setInviteeResponseHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": sel32or64(b"i", b"q")},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKMatchRequest",
        b"setRecipientResponseHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"q"},
                        },
                    }
                }
            }
        },
    )
    r(b"GKMatchRequest", b"setRestrictToAutomatch:", {"arguments": {2: {"type": b"Z"}}})
    r(
        b"GKMatchmaker",
        b"addPlayersToMatch:matchRequest:completionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKMatchmaker",
        b"findMatchForRequest:withCompletionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKMatchmaker",
        b"findPlayersForHostedMatchRequest:withCompletionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKMatchmaker",
        b"findPlayersForHostedRequest:withCompletionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKMatchmaker",
        b"inviteHandler",
        {
            "retval": {
                "callable": {
                    "retval": {"type": b"v"},
                    "arguments": {
                        0: {"type": b"^v"},
                        1: {"type": b"@"},
                        2: {"type": b"@"},
                    },
                }
            }
        },
    )
    r(
        b"GKMatchmaker",
        b"matchForInvite:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKMatchmaker",
        b"queryActivityWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": sel32or64(b"i", b"q")},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKMatchmaker",
        b"queryPlayerGroupActivity:withCompletionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": sel32or64(b"i", b"q")},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKMatchmaker",
        b"setInviteHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKMatchmaker",
        b"startBrowsingForNearbyPlayersWithHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"Z"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKMatchmaker",
        b"startBrowsingForNearbyPlayersWithReachableHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"Z"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKMatchmakerViewController",
        b"canStartWithMinimumPlayers",
        {"retval": {"type": b"Z"}},
    )
    r(b"GKMatchmakerViewController", b"isHosted", {"retval": {"type": b"Z"}})
    r(
        b"GKMatchmakerViewController",
        b"setCanStartWithMinimumPlayers:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"GKMatchmakerViewController", b"setHosted:", {"arguments": {2: {"type": b"Z"}}})
    r(
        b"GKMatchmakerViewController",
        b"setHostedPlayer:connected:",
        {"arguments": {3: {"type": b"Z"}}},
    )
    r(
        b"GKMatchmakerViewController",
        b"setHostedPlayer:didConnect:",
        {"arguments": {3: {"type": b"Z"}}},
    )
    r(
        b"GKNotificationBanner",
        b"showBannerWithTitle:message:completionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(
        b"GKNotificationBanner",
        b"showBannerWithTitle:message:duration:completionHandler:",
        {
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(b"GKPlayer", b"isFriend", {"retval": {"type": b"Z"}})
    r(b"GKPlayer", b"isInvitable", {"retval": {"type": b"Z"}})
    r(
        b"GKPlayer",
        b"loadPhotoForSize:withCompletionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKPlayer",
        b"loadPlayersForIdentifiers:withCompletionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(b"GKPlayer", b"scopedIDsArePersistent", {"retval": {"type": b"Z"}})
    r(
        b"GKSavedGame",
        b"loadDataWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKScore",
        b"challengeComposeControllerWithMessage:players:completionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"Z"},
                            3: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKScore",
        b"reportLeaderboardScores:withEligibleChallenges:withCompletionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKScore",
        b"reportScoreWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKScore",
        b"reportScores:withCompletionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKScore",
        b"reportScores:withEligibleChallenges:withCompletionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKScore",
        b"setShouldSetDefaultLeaderboard:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"GKScore", b"shouldSetDefaultLeaderboard", {"retval": {"type": b"Z"}})
    r(
        b"GKSession",
        b"acceptConnectionFromPeer:error:",
        {"retval": {"type": b"Z"}, "arguments": {3: {"type_modifier": b"o"}}},
    )
    r(b"GKSession", b"isAvailable", {"retval": {"type": b"Z"}})
    r(
        b"GKSession",
        b"sendData:toPeers:withDataMode:error:",
        {"retval": {"type": b"Z"}, "arguments": {5: {"type_modifier": b"o"}}},
    )
    r(
        b"GKSession",
        b"sendDataToAllPeers:withDataMode:error:",
        {"retval": {"type": b"Z"}, "arguments": {4: {"type_modifier": b"o"}}},
    )
    r(b"GKSession", b"setAvailable:", {"arguments": {2: {"type": b"Z"}}})
    r(
        b"GKSession",
        b"setDataReceiveHandler:withContext:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"GKTurnBasedExchange",
        b"cancelWithLocalizableMessageKey:arguments:completionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKTurnBasedExchange",
        b"replyWithLocalizableMessageKey:arguments:data:completionHandler:",
        {
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKTurnBasedMatch",
        b"acceptInviteWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKTurnBasedMatch",
        b"cancelWithLocalizableMessageKey:arguments:completionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKTurnBasedMatch",
        b"declineInviteWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKTurnBasedMatch",
        b"endMatchInTurnWithMatchData:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKTurnBasedMatch",
        b"endMatchInTurnWithMatchData:leaderboardScores:achievements:completionHandler:",
        {
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKTurnBasedMatch",
        b"endMatchInTurnWithMatchData:scores:achievements:completionHandler:",
        {
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKTurnBasedMatch",
        b"endTurnWithNextParticipant:matchData:completionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKTurnBasedMatch",
        b"endTurnWithNextParticipants:turnTimeout:matchData:completionHandler:",
        {
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKTurnBasedMatch",
        b"findMatchForRequest:withCompletionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKTurnBasedMatch",
        b"loadMatchDataWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKTurnBasedMatch",
        b"loadMatchWithID:withCompletionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKTurnBasedMatch",
        b"loadMatchesWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKTurnBasedMatch",
        b"participantQuitInTurnWithOutcome:nextParticipant:matchData:completionHandler:",
        {
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKTurnBasedMatch",
        b"participantQuitInTurnWithOutcome:nextParticipants:turnTimeout:matchData:completionHandler:",
        {
            "arguments": {
                6: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKTurnBasedMatch",
        b"participantQuitOutOfTurnWithOutcome:withCompletionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKTurnBasedMatch",
        b"rematchWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKTurnBasedMatch",
        b"removeWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKTurnBasedMatch",
        b"replyWithLocalizableMessageKey:arguments:data:completionHandler:",
        {
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKTurnBasedMatch",
        b"saveCurrentTurnWithMatchData:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKTurnBasedMatch",
        b"saveMergedMatchData:withResolvedExchanges:completionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKTurnBasedMatch",
        b"sendExchangeToParticipants:data:localizableMessageKey:arguments:timeout:completionHandler:",
        {
            "arguments": {
                7: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKTurnBasedMatch",
        b"sendReminderToParticipants:localizableMessageKey:arguments:completionHandler:",
        {
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"GKTurnBasedMatchmakerViewController",
        b"setShowExistingMatches:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"GKTurnBasedMatchmakerViewController",
        b"showExistingMatches",
        {"retval": {"type": b"Z"}},
    )
    r(b"GKVoiceChat", b"isActive", {"retval": {"type": b"Z"}})
    r(b"GKVoiceChat", b"isVoIPAllowed", {"retval": {"type": b"Z"}})
    r(
        b"GKVoiceChat",
        b"playerStateUpdateHandler",
        {
            "retval": {
                "callable": {
                    "retval": {"type": b"v"},
                    "arguments": {
                        0: {"type": b"^v"},
                        1: {"type": b"@"},
                        2: {"type": sel32or64(b"i", b"q")},
                    },
                }
            }
        },
    )
    r(
        b"GKVoiceChat",
        b"playerVoiceChatStateDidChangeHandler",
        {
            "retval": {
                "callable": {
                    "retval": {"type": b"v"},
                    "arguments": {
                        0: {"type": b"^v"},
                        1: {"type": b"@"},
                        2: {"type": sel32or64(b"i", b"q")},
                    },
                }
            }
        },
    )
    r(b"GKVoiceChat", b"setActive:", {"arguments": {2: {"type": b"Z"}}})
    r(b"GKVoiceChat", b"setMute:forPlayer:", {"arguments": {2: {"type": b"Z"}}})
    r(b"GKVoiceChat", b"setPlayer:muted:", {"arguments": {3: {"type": b"Z"}}})
    r(
        b"GKVoiceChat",
        b"setPlayerStateUpdateHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": sel32or64(b"i", b"q")},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKVoiceChat",
        b"setPlayerVoiceChatStateDidChangeHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": sel32or64(b"i", b"q")},
                        },
                    }
                }
            }
        },
    )
    r(
        b"GKVoiceChatService",
        b"acceptCallID:error:",
        {"retval": {"type": b"Z"}, "arguments": {3: {"type_modifier": b"o"}}},
    )
    r(b"GKVoiceChatService", b"isInputMeteringEnabled", {"retval": {"type": b"Z"}})
    r(b"GKVoiceChatService", b"isMicrophoneMuted", {"retval": {"type": b"Z"}})
    r(b"GKVoiceChatService", b"isOutputMeteringEnabled", {"retval": {"type": b"Z"}})
    r(b"GKVoiceChatService", b"isVoIPAllowed", {"retval": {"type": b"Z"}})
    r(
        b"GKVoiceChatService",
        b"setInputMeteringEnabled:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"GKVoiceChatService", b"setMicrophoneMuted:", {"arguments": {2: {"type": b"Z"}}})
    r(
        b"GKVoiceChatService",
        b"setOutputMeteringEnabled:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"GKVoiceChatService",
        b"startVoiceChatWithParticipantID:error:",
        {"retval": {"type": b"Z"}, "arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"NSObject",
        b"achievementViewControllerDidFinish:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"challengesViewControllerDidFinish:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"friendRequestComposeViewControllerDidFinish:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"gameCenterViewControllerDidFinish:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"handleInviteFromGameCenter:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"handleMatchEnded:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"handleTurnEventForMatch:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"handleTurnEventForMatch:didBecomeActive:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"Z"}},
        },
    )
    r(
        b"NSObject",
        b"leaderboardViewControllerDidFinish:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"localPlayerDidCompleteChallenge:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"localPlayerDidReceiveChallenge:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"localPlayerDidSelectChallenge:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"match:didFailWithError:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"match:didReceiveData:forRecipient:fromRemotePlayer:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"@"},
                4: {"type": b"@"},
                5: {"type": b"@"},
            },
        },
    )
    r(
        b"NSObject",
        b"match:didReceiveData:fromPlayer:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"match:didReceiveData:fromRemotePlayer:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"match:player:didChangeConnectionState:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"q"}},
        },
    )
    r(
        b"NSObject",
        b"match:player:didChangeState:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"q"}},
        },
    )
    r(
        b"NSObject",
        b"match:shouldReinviteDisconnectedPlayer:",
        {
            "required": False,
            "retval": {"type": b"Z"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"match:shouldReinvitePlayer:",
        {
            "required": False,
            "retval": {"type": b"Z"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"matchmakerViewController:didFailWithError:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"matchmakerViewController:didFindHostedPlayers:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"matchmakerViewController:didFindMatch:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"matchmakerViewController:didFindPlayers:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"matchmakerViewController:didReceiveAcceptFromHostedPlayer:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"matchmakerViewController:hostedPlayerDidAccept:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"matchmakerViewControllerWasCancelled:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(b"NSObject", b"participantID", {"required": True, "retval": {"type": b"@"}})
    r(
        b"NSObject",
        b"player:didAcceptInvite:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"player:didCompleteChallenge:issuedByFriend:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"player:didModifySavedGame:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"player:didReceiveChallenge:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"player:didRequestMatchWithOtherPlayers:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"player:didRequestMatchWithPlayers:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"player:didRequestMatchWithRecipients:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"player:hasConflictingSavedGames:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"player:issuedChallengeWasCompleted:byFriend:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"player:matchEnded:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"player:receivedExchangeCancellation:forMatch:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"player:receivedExchangeReplies:forCompletedExchange:forMatch:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"@"},
                4: {"type": b"@"},
                5: {"type": b"@"},
            },
        },
    )
    r(
        b"NSObject",
        b"player:receivedExchangeRequest:forMatch:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"player:receivedTurnEventForMatch:didBecomeActive:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"Z"}},
        },
    )
    r(
        b"NSObject",
        b"player:wantsToPlayChallenge:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"player:wantsToQuitMatch:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"remotePlayerDidCompleteChallenge:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"session:connectionWithPeerFailed:withError:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"session:didAddPlayer:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"session:didFailWithError:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"session:didReceiveConnectionRequestFromPeer:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"session:didReceiveData:fromPlayer:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"session:didReceiveMessage:withData:fromPlayer:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"@"},
                4: {"type": b"@"},
                5: {"type": b"@"},
            },
        },
    )
    r(
        b"NSObject",
        b"session:didRemovePlayer:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"session:peer:didChangeState:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"i"}},
        },
    )
    r(
        b"NSObject",
        b"session:player:didChangeConnectionState:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"q"}},
        },
    )
    r(
        b"NSObject",
        b"session:player:didSaveData:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"shouldShowBannerForLocallyCompletedChallenge:",
        {"required": False, "retval": {"type": b"Z"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"shouldShowBannerForLocallyReceivedChallenge:",
        {"required": False, "retval": {"type": b"Z"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"shouldShowBannerForRemotelyCompletedChallenge:",
        {"required": False, "retval": {"type": b"Z"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"turnBasedMatchmakerViewController:didFailWithError:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"turnBasedMatchmakerViewController:didFindMatch:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"turnBasedMatchmakerViewController:playerQuitForMatch:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"turnBasedMatchmakerViewControllerWasCancelled:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"voiceChatService:didNotStartWithParticipantID:error:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"voiceChatService:didReceiveInvitationFromParticipantID:callID:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"q"}},
        },
    )
    r(
        b"NSObject",
        b"voiceChatService:didStartWithParticipantID:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"voiceChatService:didStopWithParticipantID:error:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"voiceChatService:sendData:toParticipantID:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"voiceChatService:sendRealTimeData:toParticipantID:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"null",
        b"chooseBestHostPlayerWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"null",
        b"findPlayersForHostedMatchRequest:withCompletionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"null",
        b"sendData:toPlayers:withDataMode:error:",
        {"retval": {"type": b"Z"}, "arguments": {5: {"type_modifier": b"o"}}},
    )
    r(
        b"null",
        b"setInviteHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(b"null", b"setMute:forPlayer:", {"arguments": {2: {"type": b"Z"}}})
    r(
        b"null",
        b"setPlayerStateUpdateHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(
        b"null",
        b"startBrowsingForNearbyPlayersWithReachableHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"Z"},
                        },
                    }
                }
            }
        },
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



import GameKit
import objc
from PyObjCTools.TestSupport import TestCase


class TestGKGameCenterViewController(TestCase):
    def testProtocols(self):
        objc.protocolNamed("GKGameCenterControllerDelegate")

    def testConstants(self):
        self.assertEqual(GameKit.GKGameCenterViewControllerStateDefault, -1)
        self.assertEqual(GameKit.GKGameCenterViewControllerStateLeaderboards, 0)
        self.assertEqual(GameKit.GKGameCenterViewControllerStateAchievements, 1)
        self.assertEqual(GameKit.GKGameCenterViewControllerStateChallenges, 2)
        self.assertEqual(GameKit.GKGameCenterViewControllerStateLocalPlayerProfile, 3)
        self.assertEqual(GameKit.GKGameCenterViewControllerStateDashboard, 4)
        self.assertEqual(
            GameKit.GKGameCenterViewControllerStateLocalPlayerFriendsList, 5
        )



import GameKit
from PyObjCTools.TestSupport import TestCase, min_os_level, expectedFailure
import objc


class TestGKMatchMaker(TestCase):
    def testConstants(self):
        self.assertEqual(GameKit.GKInviteRecipientResponseAccepted, 0)
        self.assertEqual(GameKit.GKInviteRecipientResponseDeclined, 1)
        self.assertEqual(GameKit.GKInviteRecipientResponseFailed, 2)
        self.assertEqual(GameKit.GKInviteRecipientResponseIncompatible, 3)
        self.assertEqual(GameKit.GKInviteRecipientResponseUnableToConnect, 4)
        self.assertEqual(GameKit.GKInviteRecipientResponseNoAnswer, 5)

        self.assertEqual(
            GameKit.GKInviteeResponseAccepted, GameKit.GKInviteRecipientResponseAccepted
        )
        self.assertEqual(
            GameKit.GKInviteeResponseDeclined, GameKit.GKInviteRecipientResponseDeclined
        )
        self.assertEqual(
            GameKit.GKInviteeResponseFailed, GameKit.GKInviteRecipientResponseFailed
        )
        self.assertEqual(
            GameKit.GKInviteeResponseIncompatible,
            GameKit.GKInviteRecipientResponseIncompatible,
        )
        self.assertEqual(
            GameKit.GKInviteeResponseUnableToConnect,
            GameKit.GKInviteRecipientResponseUnableToConnect,
        )
        self.assertEqual(
            GameKit.GKInviteeResponseNoAnswer, GameKit.GKInviteRecipientResponseNoAnswer
        )

        self.assertEqual(GameKit.GKMatchTypePeerToPeer, 0)
        self.assertEqual(GameKit.GKMatchTypeHosted, 1)
        self.assertEqual(GameKit.GKMatchTypeTurnBased, 2)

    @min_os_level("10.10")
    def testMethods(self):
        self.assertArgIsBlock(
            GameKit.GKMatchmaker.addPlayersToMatch_matchRequest_completionHandler_,
            2,
            b"v@",
        )
        self.assertArgIsBlock(
            GameKit.GKMatchmaker.queryPlayerGroupActivity_withCompletionHandler_,
            1,
            b"v" + objc._C_NSInteger + b"@",
        )
        self.assertArgIsBlock(
            GameKit.GKMatchmaker.queryActivityWithCompletionHandler_,
            0,
            b"v" + objc._C_NSInteger + b"@",
        )

    @min_os_level("10.10")
    def testMethods10_8(self):
        # XXX: These aren't available on 10.9, even though the SDK claims they are
        self.assertResultIsBlock(GameKit.GKMatchmaker.inviteHandler, b"v@@")
        self.assertArgIsBlock(GameKit.GKMatchmaker.setInviteHandler_, 0, b"v@@")

        self.assertArgIsBlock(
            GameKit.GKMatchmaker.findPlayersForHostedMatchRequest_withCompletionHandler_,
            1,
            b"v@@",
        )

    @min_os_level("10.10")
    def testMethods10_9(self):
        # XXX: These aren't available on 10.9, even though the SDK claims they are
        self.assertArgIsBlock(
            GameKit.GKMatchmaker.matchForInvite_completionHandler_, 1, b"v@@"
        )

        self.assertArgIsBlock(
            GameKit.GKMatchmaker.matchForInvite_completionHandler_, 1, b"v@@"
        )

        self.assertArgIsBlock(
            GameKit.GKMatchmaker.startBrowsingForNearbyPlayersWithReachableHandler_,
            0,
            b"v@Z",
        )

    @min_os_level("10.10")
    def testMethods10_10(self):
        self.assertResultIsBlock(
            GameKit.GKMatchRequest.recipientResponseHandler, b"v@" + objc._C_NSInteger
        )
        self.assertArgIsBlock(
            GameKit.GKMatchRequest.setRecipientResponseHandler_,
            0,
            b"v@" + objc._C_NSInteger,
        )
        self.assertResultIsBlock(
            GameKit.GKMatchRequest.inviteeResponseHandler, b"v@" + objc._C_NSInteger
        )
        self.assertArgIsBlock(
            GameKit.GKMatchRequest.setInviteeResponseHandler_,
            0,
            b"v@" + objc._C_NSInteger,
        )

        self.assertArgIsBlock(
            GameKit.GKMatchmaker.findPlayersForHostedRequest_withCompletionHandler_,
            1,
            b"v@@",
        )
        self.assertArgIsBlock(
            GameKit.GKMatchmaker.startBrowsingForNearbyPlayersWithHandler_, 0, b"v@Z"
        )

    @min_os_level("10.15")
    @expectedFailure
    def testMethods10_15(self):
        self.assertResultIsBOOL(GameKit.GKMatchRequest.restrictToAutomatch)
        self.assertArgIsBOOL(GameKit.GKMatchRequest.setRestrictToAutomatch_, 0)

    def testProtocols(self):
        objc.protocolNamed("GKInviteEventListener")



import GameKit
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestGKGameSession(TestCase):
    def testConstants(self):
        self.assertEqual(GameKit.GKConnectionStateNotConnected, 0)
        self.assertEqual(GameKit.GKConnectionStateConnected, 1)

        self.assertEqual(GameKit.GKTransportTypeUnreliable, 0)
        self.assertEqual(GameKit.GKTransportTypeReliable, 1)

    @min_os_level("10.12")
    def testMethods(self):
        self.assertArgIsBlock(
            GameKit.GKGameSession.createSessionInContainer_withTitle_maxConnectedPlayers_completionHandler_,
            3,
            b"v@@",
        )
        self.assertArgIsBlock(
            GameKit.GKGameSession.loadSessionsInContainer_completionHandler_, 1, b"v@@"
        )
        self.assertArgIsBlock(
            GameKit.GKGameSession.loadSessionWithIdentifier_completionHandler_,
            1,
            b"v@@",
        )
        self.assertArgIsBlock(
            GameKit.GKGameSession.removeSessionWithIdentifier_completionHandler_,
            1,
            b"v@",
        )
        self.assertArgIsBlock(
            GameKit.GKGameSession.getShareURLWithCompletionHandler_, 0, b"v@@"
        )
        self.assertArgIsBlock(
            GameKit.GKGameSession.loadDataWithCompletionHandler_, 0, b"v@@"
        )
        self.assertArgIsBlock(
            GameKit.GKGameSession.saveData_completionHandler_, 1, b"v@@"
        )
        self.assertArgIsBlock(
            GameKit.GKGameSession.setConnectionState_completionHandler_, 1, b"v@"
        )
        self.assertArgIsBlock(
            GameKit.GKGameSession.sendData_withTransportType_completionHandler_,
            2,
            b"v@",
        )
        self.assertArgIsBOOL(
            GameKit.GKGameSession.sendMessageWithLocalizedFormatKey_arguments_data_toPlayers_badgePlayers_completionHandler_,
            4,
        )
        self.assertArgIsBlock(
            GameKit.GKGameSession.sendMessageWithLocalizedFormatKey_arguments_data_toPlayers_badgePlayers_completionHandler_,
            5,
            b"v@",
        )
        self.assertArgIsBlock(
            GameKit.GKGameSession.clearBadgeForPlayers_completionHandler_, 1, b"v@"
        )



import GameKit
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestGKScore(TestCase):
    @min_os_level("10.8")
    def testMethods(self):
        self.assertResultIsBOOL(GameKit.GKScore.shouldSetDefaultLeaderboard)
        self.assertArgIsBOOL(GameKit.GKScore.setShouldSetDefaultLeaderboard_, 0)

        self.assertArgIsBlock(
            GameKit.GKScore.reportScores_withCompletionHandler_, 1, b"v@"
        )

        self.assertArgIsBlock(
            GameKit.GKScore.reportScoreWithCompletionHandler_, 0, b"v@"
        )



import GameKit
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestGKSavedGame(TestCase):
    @min_os_level("10.10")
    def testMethods10_10(self):
        self.assertArgIsBlock(
            GameKit.GKSavedGame.loadDataWithCompletionHandler_, 0, b"v@@"
        )

        self.assertArgIsBlock(
            GameKit.GKLocalPlayer.fetchSavedGamesWithCompletionHandler_, 0, b"v@@"
        )
        self.assertArgIsBlock(
            GameKit.GKLocalPlayer.saveGameData_withName_completionHandler_, 2, b"v@@"
        )
        self.assertArgIsBlock(
            GameKit.GKLocalPlayer.deleteSavedGamesWithName_completionHandler_, 1, b"v@"
        )
        self.assertArgIsBlock(
            GameKit.GKLocalPlayer.resolveConflictingSavedGames_withData_completionHandler_,
            2,
            b"v@@",
        )



import GameKit
from PyObjCTools.TestSupport import TestCase, min_os_level
import objc


class TestGKTurnBasedMatchHelper(GameKit.NSObject):
    def player_receivedTurnEventForMatch_didBecomeActive_(self, p, m, a):
        pass

    def handleTurnEventForMatch_didBecomeActive_(self, m, a):
        pass


class TestGKTurnBasedMatch(TestCase):
    def testConstants(self):
        self.assertEqual(GameKit.GKTurnBasedMatchStatusUnknown, 0)
        self.assertEqual(GameKit.GKTurnBasedMatchStatusOpen, 1)
        self.assertEqual(GameKit.GKTurnBasedMatchStatusEnded, 2)
        self.assertEqual(GameKit.GKTurnBasedMatchStatusMatching, 3)

        self.assertEqual(GameKit.GKTurnBasedParticipantStatusUnknown, 0)
        self.assertEqual(GameKit.GKTurnBasedParticipantStatusInvited, 1)
        self.assertEqual(GameKit.GKTurnBasedParticipantStatusDeclined, 2)
        self.assertEqual(GameKit.GKTurnBasedParticipantStatusMatching, 3)
        self.assertEqual(GameKit.GKTurnBasedParticipantStatusActive, 4)
        self.assertEqual(GameKit.GKTurnBasedParticipantStatusDone, 5)

        self.assertEqual(GameKit.GKTurnBasedMatchOutcomeNone, 0)
        self.assertEqual(GameKit.GKTurnBasedMatchOutcomeQuit, 1)
        self.assertEqual(GameKit.GKTurnBasedMatchOutcomeWon, 2)
        self.assertEqual(GameKit.GKTurnBasedMatchOutcomeLost, 3)
        self.assertEqual(GameKit.GKTurnBasedMatchOutcomeTied, 4)
        self.assertEqual(GameKit.GKTurnBasedMatchOutcomeTimeExpired, 5)
        self.assertEqual(GameKit.GKTurnBasedMatchOutcomeFirst, 6)
        self.assertEqual(GameKit.GKTurnBasedMatchOutcomeSecond, 7)
        self.assertEqual(GameKit.GKTurnBasedMatchOutcomeThird, 8)
        self.assertEqual(GameKit.GKTurnBasedMatchOutcomeFourth, 9)

        self.assertEqual(GameKit.GKTurnBasedMatchOutcomeCustomRange, 0x00FF0000)

        self.assertEqual(GameKit.GKTurnBasedExchangeStatusUnknown, 0)
        self.assertEqual(GameKit.GKTurnBasedExchangeStatusActive, 1)
        self.assertEqual(GameKit.GKTurnBasedExchangeStatusComplete, 2)
        self.assertEqual(GameKit.GKTurnBasedExchangeStatusResolved, 3)
        self.assertEqual(GameKit.GKTurnBasedExchangeStatusCanceled, 4)

    @min_os_level("10.10")
    def testConstants10_10(self):
        self.assertIsInstance(GameKit.GKExchangeTimeoutDefault, float)
        self.assertIsInstance(GameKit.GKExchangeTimeoutNone, float)

    @min_os_level("10.9")
    def testConstants10_9(self):
        self.assertIsInstance(GameKit.GKTurnTimeoutDefault, float)
        self.assertIsInstance(GameKit.GKTurnTimeoutNone, float)

    def testProtocols(self):
        objc.protocolNamed("GKTurnBasedEventListener")
        objc.protocolNamed("GKTurnBasedEventHandlerDelegate")

    def testMethods(self):
        self.assertArgIsBOOL(
            TestGKTurnBasedMatchHelper.player_receivedTurnEventForMatch_didBecomeActive_,
            2,
        )
        self.assertArgIsBOOL(
            TestGKTurnBasedMatchHelper.handleTurnEventForMatch_didBecomeActive_, 1
        )

        self.assertArgIsBlock(
            GameKit.GKTurnBasedMatch.findMatchForRequest_withCompletionHandler_,
            1,
            b"v@@",
        )
        self.assertArgIsBlock(
            GameKit.GKTurnBasedMatch.loadMatchesWithCompletionHandler_, 0, b"v@@"
        )
        self.assertArgIsBlock(
            GameKit.GKTurnBasedMatch.removeWithCompletionHandler_, 0, b"v@"
        )
        self.assertArgIsBlock(
            GameKit.GKTurnBasedMatch.loadMatchDataWithCompletionHandler_, 0, b"v@@"
        )

        self.assertArgIsBlock(
            GameKit.GKTurnBasedMatch.endMatchInTurnWithMatchData_completionHandler_,
            1,
            b"v@",
        )

    @min_os_level("10.8")
    def testMethods10_8(self):
        self.assertArgIsBlock(
            GameKit.GKTurnBasedMatch.loadMatchWithID_withCompletionHandler_, 1, b"v@@"
        )
        self.assertArgIsBlock(
            GameKit.GKTurnBasedMatch.acceptInviteWithCompletionHandler_, 0, b"v@@"
        )
        self.assertArgIsBlock(
            GameKit.GKTurnBasedMatch.declineInviteWithCompletionHandler_, 0, b"v@"
        )
        self.assertArgIsBlock(
            GameKit.GKTurnBasedMatch.saveCurrentTurnWithMatchData_completionHandler_,
            1,
            b"v@",
        )

        self.assertArgIsBlock(
            GameKit.GKTurnBasedMatch.endTurnWithNextParticipant_matchData_completionHandler_,
            2,
            b"v@",
        )
        self.assertArgIsBlock(
            GameKit.GKTurnBasedMatch.participantQuitInTurnWithOutcome_nextParticipant_matchData_completionHandler_,
            3,
            b"v@",
        )

    @min_os_level("10.9")
    def testMethods10_9(self):
        self.assertArgIsBlock(
            GameKit.GKTurnBasedMatch.rematchWithCompletionHandler_, 0, b"v@@"
        )
        self.assertArgIsBlock(
            GameKit.GKTurnBasedMatch.endTurnWithNextParticipants_turnTimeout_matchData_completionHandler_,
            3,
            b"v@",
        )
        self.assertArgIsBlock(
            GameKit.GKTurnBasedMatch.participantQuitInTurnWithOutcome_nextParticipants_turnTimeout_matchData_completionHandler_,
            4,
            b"v@",
        )
        self.assertArgIsBlock(
            GameKit.GKTurnBasedMatch.participantQuitOutOfTurnWithOutcome_withCompletionHandler_,
            1,
            b"v@",
        )
        self.assertArgIsBlock(
            GameKit.GKTurnBasedMatch.endMatchInTurnWithMatchData_completionHandler_,
            1,
            b"v@",
        )

    @min_os_level("10.10")
    def testMethods10_10(self):
        self.assertArgIsBlock(
            GameKit.GKTurnBasedMatch.endMatchInTurnWithMatchData_scores_achievements_completionHandler_,
            3,
            b"v@",
        )
        self.assertArgIsBlock(
            GameKit.GKTurnBasedMatch.saveMergedMatchData_withResolvedExchanges_completionHandler_,
            2,
            b"v@",
        )
        self.assertArgIsBlock(
            GameKit.GKTurnBasedMatch.sendExchangeToParticipants_data_localizableMessageKey_arguments_timeout_completionHandler_,
            5,
            b"v@@",
        )
        self.assertArgIsBlock(
            GameKit.GKTurnBasedMatch.sendReminderToParticipants_localizableMessageKey_arguments_completionHandler_,
            3,
            b"v@",
        )

        self.assertArgIsBlock(
            GameKit.GKTurnBasedExchange.cancelWithLocalizableMessageKey_arguments_completionHandler_,
            2,
            b"v@",
        )
        self.assertArgIsBlock(
            GameKit.GKTurnBasedExchange.replyWithLocalizableMessageKey_arguments_data_completionHandler_,
            3,
            b"v@",
        )



import GameKit
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestGKAchievementHelper(GameKit.GKAchievement):
    def isHidden(self):
        return 1


class TestGKAchievement(TestCase):
    def testMethods(self):
        self.assertArgIsBlock(
            GameKit.GKAchievement.loadAchievementsWithCompletionHandler_, 0, b"v@@"
        )
        self.assertArgIsBlock(
            GameKit.GKAchievement.resetAchievementsWithCompletionHandler_, 0, b"v@"
        )
        self.assertArgIsBlock(
            GameKit.GKAchievement.reportAchievements_withCompletionHandler_, 1, b"v@"
        )

        self.assertResultIsBOOL(GameKit.GKAchievement.isCompleted)

        self.assertArgIsBlock(
            GameKit.GKAchievement.reportAchievementWithCompletionHandler_, 0, b"v@"
        )

        self.assertResultIsBOOL(TestGKAchievementHelper.isHidden)

    @min_os_level("10.10")
    def testMethods10_10(self):
        # Availability macro claims this is avaible on 10.8, but it isn't on 10.9
        self.assertResultIsBOOL(GameKit.GKAchievement.showsCompletionBanner)
        self.assertArgIsBOOL(GameKit.GKAchievement.setShowsCompletionBanner_, 0)



import GameKit
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestGKPlayerHelper(GameKit.GKPlayer):
    def isFriend(self):
        return 1


class TestGKPlayer(TestCase):
    def testConstants(self):
        self.assertEqual(GameKit.GKPhotoSizeSmall, 0)
        self.assertEqual(GameKit.GKPhotoSizeNormal, 1)

    @min_os_level("11.0")
    def testConstants11_0(self):
        self.assertIsInstance(GameKit.GKPlayerIDNoLongerAvailable, str)

    def testMethods(self):
        self.assertArgIsBlock(
            GameKit.GKPlayer.loadPlayersForIdentifiers_withCompletionHandler_, 1, b"v@@"
        )

    @min_os_level("10.8")
    def testMethods10_8(self):
        self.assertArgIsBlock(
            GameKit.GKPlayer.loadPhotoForSize_withCompletionHandler_, 1, b"v@@"
        )

        self.assertResultIsBOOL(TestGKPlayerHelper.isFriend)

    @min_os_level("10.15")
    def testMethods10_15(self):
        self.assertResultIsBOOL(GameKit.GKPlayer.scopedIDsArePersistent)

    @min_os_level("11.0")
    def testMethods11_0(self):
        self.assertResultIsBOOL(GameKit.GKPlayer.isInvitable)



"""
Python mapping for the GameKit framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""

import sys

import Cocoa
import objc
from GameKit import _metadata
from GameKit import _GameKit

sys.modules["GameKit"] = mod = objc.ObjCLazyModule(
    "GameKit",
    "com.apple.GameKit",
    objc.pathForFramework("/System/Library/Frameworks/GameKit.framework"),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "objc": objc,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
    },
    (_GameKit, Cocoa),
)


del sys.modules["GameKit._metadata"]



import GameKit
import objc
from PyObjCTools.TestSupport import TestCase, min_os_level, expectedFailure


class TestGKLeaderboard(TestCase):
    def testConstants(self):
        self.assertEqual(GameKit.GKLeaderboardTimeScopeToday, 0)
        self.assertEqual(GameKit.GKLeaderboardTimeScopeWeek, 1)
        self.assertEqual(GameKit.GKLeaderboardTimeScopeAllTime, 2)

        self.assertEqual(GameKit.GKLeaderboardPlayerScopeGlobal, 0)
        self.assertEqual(GameKit.GKLeaderboardPlayerScopeFriendsOnly, 1)

    def testMethods(self):
        self.assertArgIsBlock(
            GameKit.GKLeaderboard.loadLeaderboardsWithCompletionHandler_, 0, b"v@@"
        )
        self.assertArgIsBlock(
            GameKit.GKLeaderboard.loadCategoriesWithCompletionHandler_, 0, b"v@@@"
        )
        self.assertArgIsBlock(
            GameKit.GKLeaderboard.setDefaultLeaderboard_withCompletionHandler_, 1, b"v@"
        )
        self.assertArgIsBlock(
            GameKit.GKLeaderboard.loadImageWithCompletionHandler_, 0, b"v@@"
        )

    @min_os_level("10.10")
    def testMethods10_10(self):
        self.assertResultIsBOOL(GameKit.GKLeaderboard.isLoading)
        self.assertArgIsBlock(
            GameKit.GKLeaderboard.loadScoresWithCompletionHandler_, 0, b"v@@"
        )

    @min_os_level("11.0")
    def test_methods11_0(self):
        self.assertArgIsBlock(
            GameKit.GKLeaderboard.loadLeaderboardsWithIDs_completionHandler_, 1, b"v@@"
        )
        self.assertArgIsBlock(
            GameKit.GKLeaderboard.loadPreviousOccurrenceWithCompletionHandler_,
            0,
            b"v@@",
        )
        self.assertArgIsBlock(
            GameKit.GKLeaderboard.submitScore_context_player_completionHandler_,
            3,
            b"v@",
        )
        self.assertArgIsBlock(
            GameKit.GKLeaderboard.loadEntriesForPlayerScope_timeScope_range_completionHandler_,
            3,
            b"v@@" + objc._C_NSInteger + b"@",
        )
        self.assertArgIsBlock(
            GameKit.GKLeaderboard.loadEntriesForPlayers_timeScope_completionHandler_,
            2,
            b"v@@@",
        )

    @expectedFailure
    @min_os_level("11.0")
    def test_methods11_0_missing(self):
        self.assertArgIsBlock(
            GameKit.GKLeaderboard.submitScore_context_player_loaderboardIDs_completionHandler_,
            4,
            b"v@",
        )



import GameKit
from PyObjCTools.TestSupport import TestCase


class TestGKSession(TestCase):
    def testMethods(self):
        self.assertResultIsBOOL(GameKit.GKSession.isAvailable)
        self.assertArgIsBOOL(GameKit.GKSession.setAvailable_, 0)

        self.assertResultIsBOOL(GameKit.GKSession.sendData_toPeers_withDataMode_error_)
        self.assertArgIsOut(GameKit.GKSession.sendData_toPeers_withDataMode_error_, 3)

        self.assertResultIsBOOL(
            GameKit.GKSession.sendDataToAllPeers_withDataMode_error_
        )
        self.assertArgIsOut(GameKit.GKSession.sendDataToAllPeers_withDataMode_error_, 2)

        self.assertResultIsBOOL(GameKit.GKSession.acceptConnectionFromPeer_error_)
        self.assertArgIsOut(GameKit.GKSession.acceptConnectionFromPeer_error_, 1)



import GameKit
from PyObjCTools.TestSupport import TestCase, min_os_level
import objc


class TestGKMatchmakerViewController(TestCase):
    def test_constants(self):
        self.assertEqual(GameKit.GKMatchmakingModeDefault, 0)
        self.assertEqual(GameKit.GKMatchmakingModeNearbyOnly, 1)
        self.assertEqual(GameKit.GKMatchmakingModeAutomatchOnly, 2)
        self.assertEqual(GameKit.GKMatchmakingModeInviteOnly, 3)

    def testMethods(self):
        self.assertResultIsBOOL(GameKit.GKMatchmakerViewController.isHosted)
        self.assertArgIsBOOL(GameKit.GKMatchmakerViewController.setHosted_, 0)

    @min_os_level("10.8")
    def testMethods10_8(self):
        self.assertArgIsBOOL(
            GameKit.GKMatchmakerViewController.setHostedPlayer_connected_, 1
        )

    @min_os_level("10.10")
    def testMethods10_10(self):
        self.assertArgIsBOOL(
            GameKit.GKMatchmakerViewController.setHostedPlayer_didConnect_, 1
        )

    @min_os_level("12.0")
    def testMethods12_0(self):
        self.assertResultIsBOOL(
            GameKit.GKMatchmakerViewController.canStartWithMinimumPlayers
        )
        self.assertArgIsBOOL(
            GameKit.GKMatchmakerViewController.setCanStartWithMinimumPlayers_, 0
        )

    def testProtocols(self):
        objc.protocolNamed("GKMatchmakerViewControllerDelegate")



import GameKit
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestGKCloudPlayer(TestCase):
    @min_os_level("10.12")
    def testMethods(self):
        self.assertArgIsBlock(
            GameKit.GKCloudPlayer.getCurrentSignedInPlayerForContainer_completionHandler_,
            1,
            b"v@@",
        )



import GameKit
from PyObjCTools.TestSupport import TestCase, min_os_level
import objc


class TestGKMatchHelper(GameKit.NSObject):
    def match_player_didChangeConnectionState_(self, m, p, s):
        pass

    def match_player_didChangeState_(self, m, p, s):
        pass

    def match_shouldReinviteDisconnectedPlayer_(self, m, p):
        return 1

    def match_shouldReinvitePlayer_(self, m, p):
        return 1


class TestGKMatch(TestCase):
    def testConstants(self):
        self.assertEqual(GameKit.GKMatchSendDataReliable, 0)
        self.assertEqual(GameKit.GKMatchSendDataUnreliable, 1)

        self.assertEqual(GameKit.GKPlayerStateUnknown, 0)
        self.assertEqual(GameKit.GKPlayerStateConnected, 1)
        self.assertEqual(GameKit.GKPlayerStateDisconnected, 2)

    @min_os_level("10.10")
    def testMethods(self):
        self.assertResultIsBOOL(GameKit.GKMatch.sendData_toPlayers_dataMode_error_)
        self.assertArgIsOut(GameKit.GKMatch.sendData_toPlayers_dataMode_error_, 3)

        self.assertResultIsBOOL(
            GameKit.GKMatch.sendDataToAllPlayers_withDataMode_error_
        )
        self.assertArgIsOut(GameKit.GKMatch.sendDataToAllPlayers_withDataMode_error_, 2)

    def testProtocolMethods(self):
        self.assertArgHasType(
            GameKit.TestGKMatchHelper.match_player_didChangeConnectionState_,
            2,
            objc._C_NSInteger,
        )
        self.assertArgHasType(
            GameKit.TestGKMatchHelper.match_player_didChangeState_, 2, objc._C_NSInteger
        )
        self.assertResultIsBOOL(
            GameKit.TestGKMatchHelper.match_shouldReinviteDisconnectedPlayer_
        )
        self.assertResultIsBOOL(GameKit.TestGKMatchHelper.match_shouldReinvitePlayer_)

    @min_os_level("10.10")
    def testMethods10_9(self):
        self.assertArgIsBlock(GameKit.GKMatch.rematchWithCompletionHandler_, 0, b"v@@")
        self.assertArgIsBlock(
            GameKit.GKMatch.chooseBestHostPlayerWithCompletionHandler_, 0, b"v@"
        )

        self.assertResultIsBOOL(GameKit.GKMatch.sendData_toPlayers_withDataMode_error_)
        self.assertArgIsOut(GameKit.GKMatch.sendData_toPlayers_withDataMode_error_, 3)

    @min_os_level("10.10")
    def testMethods10_10(self):
        self.assertArgIsBlock(
            GameKit.GKMatch.chooseBestHostingPlayerWithCompletionHandler_, 0, b"v@"
        )

    def testProtocols(self):
        objc.protocolNamed("GKMatchDelegate")



import GameKit
from PyObjCTools.TestSupport import TestCase
import objc


class TestGKPublicProtocolsHelper(GameKit.NSObject):
    def session_peer_didChangeState_(self, s, p, st):
        pass


class TestGKPublicProtocols(TestCase):
    def testProtocols(self):
        objc.protocolNamed("GKSessionDelegate")
        objc.protocolNamed("GKVoiceChatClient")

    def testMethods(self):
        self.assertArgHasType(
            TestGKPublicProtocolsHelper.session_peer_didChangeState_, 2, b"i"
        )



import GameKit
from PyObjCTools.TestSupport import TestCase, min_os_level
import objc


class TestGKLocalPlayerHelper(GameKit.GKLocalPlayer):
    def isUnderage(self):
        return 1


class TestGKLocalPlayer(TestCase):
    @min_os_level("10.10")
    def testMethods(self):
        self.assertResultIsBOOL(GameKit.GKLocalPlayer.isAuthenticated)
        self.assertResultIsBOOL(TestGKLocalPlayerHelper.isUnderage)

        self.assertArgIsBlock(
            GameKit.GKLocalPlayer.setDefaultLeaderboardCategoryID_completionHandler_,
            1,
            b"v@",
        )
        self.assertArgIsBlock(
            GameKit.GKLocalPlayer.loadDefaultLeaderboardCategoryIDWithCompletionHandler_,
            0,
            b"v@@",
        )
        self.assertArgIsBlock(
            GameKit.GKLocalPlayer.loadFriendsWithCompletionHandler_, 0, b"v@@"
        )
        self.assertArgIsBlock(
            GameKit.GKLocalPlayer.authenticateWithCompletionHandler_, 0, b"v@"
        )

    @min_os_level("10.10")
    def testMethods10_9(self):
        self.assertResultIsBlock(GameKit.GKLocalPlayer.authenticateHandler, b"v@@")
        self.assertArgIsBlock(GameKit.GKLocalPlayer.setAuthenticateHandler_, 0, b"v@@")

    @min_os_level("10.10")
    def testMethods10_10(self):
        self.assertArgIsBlock(
            GameKit.GKLocalPlayer.setDefaultLeaderboardIdentifier_completionHandler_,
            1,
            b"v@",
        )
        self.assertArgIsBlock(
            GameKit.GKLocalPlayer.loadDefaultLeaderboardIdentifierWithCompletionHandler_,
            0,
            b"v@@",
        )
        self.assertArgIsBlock(
            GameKit.GKLocalPlayer.generateIdentityVerificationSignatureWithCompletionHandler_,
            0,
            b"v@@@Q@",
        )
        self.assertArgIsBlock(
            GameKit.GKLocalPlayer.loadFriendPlayersWithCompletionHandler_, 0, b"v@@"
        )

    @min_os_level("10.11")
    def testMethods10_11(self):
        self.assertArgIsBlock(
            GameKit.GKLocalPlayer.loadRecentPlayersWithCompletionHandler_, 0, b"v@@"
        )

    @min_os_level("10.15")
    def testMethods10_15(self):
        self.assertResultIsBOOL(GameKit.GKLocalPlayer.isMultiplayerGamingRestricted)
        self.assertArgIsBlock(
            GameKit.GKLocalPlayer.loadChallengableFriendsWithCompletionHandler_,
            0,
            b"v@@",
        )

    @min_os_level("10.15.4")
    def testMethods10_15_4(self):
        # XXX: Header says 10.15.5
        self.assertArgIsBlock(
            GameKit.GKLocalPlayer.fetchItemsForIdentityVerificationSignature_,
            0,
            b"v@@@Q@",
        )

    @min_os_level("11.0")
    def testMethods11_0(self):
        self.assertResultIsBOOL(
            GameKit.GKLocalPlayer.isPersonalizedCommunicationRestricted
        )

    @min_os_level("11.3")
    def testMethods11_3(self):
        self.assertArgIsBlock(
            GameKit.GKLocalPlayer.loadFriendsAuthorizationStatus_,
            0,
            b"v" + objc._C_NSInteger + b"@",
        )
        self.assertArgIsBlock(GameKit.GKLocalPlayer.loadFriends_, 0, b"v@@")
        self.assertArgIsBlock(
            GameKit.GKLocalPlayer.loadFriendsWithIdentifiers_completionHandler_,
            1,
            b"v@@",
        )

    @min_os_level("12.0")
    def testMethods12_0(self):
        self.assertResultIsBOOL(
            GameKit.GKLocalPlayer.isPresentingFriendRequestViewController
        )

    def testProtocols(self):
        objc.protocolNamed("GKLocalPlayerListener")

    def testConstants(self):
        self.assertIsInstance(
            GameKit.GKPlayerAuthenticationDidChangeNotificationName, str
        )

        self.assertEqual(GameKit.GKAuthenticatingWithoutUI, 0)
        self.assertEqual(GameKit.GKAuthenticatingWithGreenBuddyUI, 1)
        self.assertEqual(GameKit.GKAuthenticatingWithAuthKitInvocation, 2)

        self.assertEqual(GameKit.GKFriendsAuthorizationStatusNotDetermined, 0)
        self.assertEqual(GameKit.GKFriendsAuthorizationStatusRestricted, 1)
        self.assertEqual(GameKit.GKFriendsAuthorizationStatusDenied, 2)
        self.assertEqual(GameKit.GKFriendsAuthorizationStatusAuthorized, 3)



import GameKit
from PyObjCTools.TestSupport import TestCase, min_os_level
import objc


class TestGKVoiceChat(TestCase):
    def testConstants(self):
        self.assertEqual(GameKit.GKVoiceChatPlayerConnected, 0)
        self.assertEqual(GameKit.GKVoiceChatPlayerDisconnected, 1)
        self.assertEqual(GameKit.GKVoiceChatPlayerSpeaking, 2)
        self.assertEqual(GameKit.GKVoiceChatPlayerSilent, 3)
        self.assertEqual(GameKit.GKVoiceChatPlayerConnecting, 4)

    @min_os_level("10.10")
    def testMethods10_10(self):
        self.assertArgIsBOOL(GameKit.GKVoiceChat.setPlayer_muted_, 1)

        self.assertArgIsBlock(
            GameKit.GKVoiceChat.setPlayerVoiceChatStateDidChangeHandler_,
            0,
            b"v@" + objc._C_NSInteger,
        )
        self.assertResultIsBlock(
            GameKit.GKVoiceChat.playerVoiceChatStateDidChangeHandler,
            b"v@" + objc._C_NSInteger,
        )

    @min_os_level("10.10")
    def testMethods10_8(self):
        # XXX: For some reason most of these aren't actually available when testing on 10.9
        self.assertArgIsBOOL(GameKit.GKVoiceChat.setActive_, 0)
        self.assertResultIsBOOL(GameKit.GKVoiceChat.isActive)

        self.assertResultIsBOOL(GameKit.GKVoiceChat.isVoIPAllowed)

        self.assertArgIsBlock(
            GameKit.GKVoiceChat.setPlayerStateUpdateHandler_,
            0,
            b"v@" + objc._C_NSInteger,
        )
        self.assertResultIsBlock(
            GameKit.GKVoiceChat.playerStateUpdateHandler, b"v@" + objc._C_NSInteger
        )

        self.assertArgIsBOOL(GameKit.GKVoiceChat.setMute_forPlayer_, 0)
